class PdfResultsController < ApplicationController
  model_data_store(PdfResult, {create: true, read: true, update: true, delete: true, index: true}, {delete: true})
  before_action :set_target, only: [:show, :update, :destroy, :download, :rerun]

  def run
    @model = PdfResult.create(run_params)
    GenerationJob.perform_later(@model[:id], RxModule::Authorization.current_user_token)
    render json: @model, status: :accepted
  end

  def rerun
    @model.update(generating: true, generation_percent: 0, generation_error: nil)
    GenerationJob.perform_later(@model.id, RxModule::Authorization.current_user_token)
    render json: @model, status: :accepted
  end

  def download
    if @model.generating
      head :accepted
    elsif @model.generation_error && @model.generation_error != ""
      render json: @model, status: 500
    else
      response.headers["Content-Type"] = "application/pdf"
      response.headers["Content-Disposition"] = "attachment; filename=\"#{@model.name || "result"}.pdf\""

      @model.data_file.download do |chunk|
        response.stream.write(chunk)
      end
    end
  end

  private

  def check_authorization!
    return super unless params["action"] == "download"
    set_target
    if (!@model[:module_id] || !@model[:target_id] || !@model[:action_id]) || RxModule::Authorization.current_user_can?(@model[:target_id], @model[:action_id], @model[:module_id])
      true
    else
      Rails.logger.warn { {msg: "Unauthorized access attempted", pdf: @model.id, user: RxModule::Authorization.current_user} }
      head :forbidden
    end
  end

  def run_params
    resolved_params = params.require(:pdf_result).permit(:name, :notes, :module_id, :target_id, :action_id, :template_id, sources: [:url, :render_selector], local_storage: [:name, :value])
    resolved_params["sources"] = resolved_params["sources"].to_json
    resolved_params["local_storage"] = resolved_params["local_storage"].to_json
    resolved_params["generating"] = true
    resolved_params
  end
end
