import * as React from 'react';
import {CircularProgress, IconButton} from "@material-ui/core";
import {observer} from "mobx-react-lite";
import {GetApp, Replay} from "@material-ui/icons";
import {PdfResultModel} from "../../stores/PdfResultStore";
import {ButtonField} from "@rx-suite/ui";
import {t} from "@lingui/macro";

export const ResultDownloadButton: React.FunctionComponent<{ result: PdfResultModel, compact?: boolean }> = observer(({
                                                                                                                          result,
                                                                                                                          compact
                                                                                                                      }) => {
    if (result.isDone) {
        if (compact) {
            return <IconButton onClick={result.download}>
                <GetApp/>
            </IconButton>
        } else {
            return <ButtonField startIcon={<GetApp/>} text={t`Download`} onClick={result.download}/>
        }
    } else if (result.generating) {
        return <CircularProgress size={24}/>
    } else if (result.generation_error) {
        if (compact) {
            return <IconButton onClick={result.rerun}>
                <Replay/>
            </IconButton>
        } else {
            return <ButtonField startIcon={<Replay/>} text={t`Rerun`} onClick={result.rerun}/>
        }
    } else {
        return null;
    }
});

