import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {PdfResultModel, PdfResultStore} from "../../stores/PdfResultStore";
import {ResultsForm} from "./ResultsForm";
import {t} from "@lingui/macro";
import {ModuleIDCell} from "../../components/results/ModuleIDCell";
import {ResultStatus} from "../../components/results/ResultStatus";
import {Model} from "@rx-suite/data";
import {ResultDownloadButton} from "../../components/results/ResultDownloadButton";

export const ResultsBreadModel = () => {
    const actions = React.useCallback((mod: Model) => {
        return <ResultDownloadButton result={mod as PdfResultModel} compact/>
    }, []);
    const columns = [
        makeColumn('created_at', t`Created`, "date"),
        makeColumn('name', t`Name`, "string"),
        makeColumn('notes', t`Note`, "string", val => {
            return (val || '').split("\n").map((v: string) => <React.Fragment key={v}>{v}<br/></React.Fragment>)
        }),
        {
            Header: t`Module`,
            accessor: (d: unknown) => d as PdfResultModel,
            id: 'module_id',
            Cell: (cellInfo: { value: PdfResultModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <ModuleIDCell result={cellInfo.value}/>
            },
            sortable: false,
            filterable: false
        },
        {
            Header: t`Status`,
            accessor: (d: unknown) => d as PdfResultModel,
            id: 'generating',
            style: {textAlign: "center"},
            width: 200,
            Cell: (cellInfo: { value: PdfResultModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <ResultStatus result={cellInfo.value}/>
            },
            sortable: false,
            filterable: false
        }
    ];
    return (
        <BreadModel store={PdfResultStore} Form={ResultsForm} columns={columns}
                    tableProps={{customActions: actions, defaultSorted: [{id: 'created_at', desc: true}]}}/>
    )
};
