import * as React from 'react';
import {observer} from "mobx-react-lite";
import {FormProps, LinkButton, PaddedPaper} from "@rx-suite/ui";
import {Table, TableBody, TableCell, TableRow} from "@material-ui/core";
import {t} from "@lingui/macro";
import {PdfResultModel} from "../../stores/PdfResultStore";
import {ResultStatus} from "../../components/results/ResultStatus";
import {ResultDownloadButton} from "../../components/results/ResultDownloadButton";
import {ModuleIDCell} from "../../components/results/ModuleIDCell";
import moment from "moment";
import {MenuOpen} from "@material-ui/icons";

export const ResultsForm: React.FunctionComponent<FormProps> = observer(({model}) => {
    return (
        <PaddedPaper>
            <LinkButton to={model.listLink as string} color={"primary"} noGutter><MenuOpen/> {t`List`}</LinkButton>
            <Table>
                <TableBody>
                    <TableRow>
                        <TableCell>{t`Name`}</TableCell>
                        <TableCell>{model.name}</TableCell>
                    </TableRow>
                    <TableRow>
                        <TableCell>{t`Description`}</TableCell>
                        <TableCell>{model.notes}</TableCell>
                    </TableRow>
                    <TableRow>
                        <TableCell>{t`Module`}</TableCell>
                        <TableCell><ModuleIDCell result={model as PdfResultModel}/></TableCell>
                    </TableRow>
                    <TableRow>
                        <TableCell>{t`Status`}</TableCell>
                        <TableCell>
                            <ResultStatus result={model as PdfResultModel}/>
                            <ResultDownloadButton result={model as PdfResultModel}/>
                        </TableCell>
                    </TableRow>
                    <TableRow>
                        <TableCell>{t`Created`}</TableCell>
                        <TableCell>{moment(model.created_at as Date).format("YYYY-MM-DD HH:mm")}</TableCell>
                    </TableRow>
                </TableBody>
            </Table>
            <ResultDownloadButton result={model as PdfResultModel}/>
        </PaddedPaper>
    )
});
