import * as React from 'react';
import {BreadModel, makeColumn} from "@rx-suite/ui";
import {TemplateModel, TemplateStore} from "../../stores/TemplateStore";
import {TemplateForm} from "./TemplateForm";
import {t} from "@lingui/macro";
import {Grid} from "@material-ui/core";

export const TemplateBreadModel = () => {
    const columns = [
        makeColumn('name', t`Name`, "string"),
        makeColumn('desc', t`Description`, "string", val => {
            return (val || '').split("\n").map((v: string) => <React.Fragment key={v}>{v}<br/></React.Fragment>)
        }),
        {
            accessor: (d: TemplateModel) => d,
            id: '_dimensions',
            Cell: (cellInfo: { value: TemplateModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <div>
                    {cellInfo.value.width} {cellInfo.value.length_unit} x {cellInfo.value.height} {cellInfo.value.length_unit}
                </div>;
            },
            Header: t`Width x Height`,
            sortable: false,
            filterable: false
        },
        {
            accessor: (d: TemplateModel) => d,
            id: '_margins',
            Cell: (cellInfo: { value: TemplateModel }) => {
                if (!cellInfo.value || !cellInfo.value.getId) {
                    return null;
                }
                return <Grid container>
                    {/*row 1*/}
                    <Grid item xs={4}/>
                    <Grid item xs={4}>
                        {cellInfo.value.margin_top || 0} {cellInfo.value.length_unit}
                    </Grid>
                    <Grid item xs={4}/>
                    {/*row 2*/}
                    <Grid item xs={4}>
                        {cellInfo.value.margin_left || 0} {cellInfo.value.length_unit}
                    </Grid>
                    <Grid item xs={4}/>
                    <Grid item xs={4}>
                        {cellInfo.value.margin_right || 0} {cellInfo.value.length_unit}
                    </Grid>
                    {/*row 3*/}
                    <Grid item xs={4}/>
                    <Grid item xs={4}>
                        {cellInfo.value.margin_bottom || 0} {cellInfo.value.length_unit}
                    </Grid>
                    <Grid item xs={4}/>
                </Grid>;
            },
            Header: t`Margins`,
            sortable: false,
            filterable: false
        },
    ];
    return (
        <BreadModel store={TemplateStore} Form={TemplateForm} columns={columns}/>
    )
};
